# OSBITS
IF (NOT OSBITS)
	IF (CMAKE_SIZEOF_VOID_P EQUAL 4)
		SET (OSBITS "32")
	ELSE ()
		SET (OSBITS "64")
	ENDIF ()
ENDIF ()


# OSARCH
IF (NOT OSARCH)
	IF (WIN32)
		IF (OSBITS STREQUAL "32")
			SET (OSARCH "x86")
		ELSE ()
			SET (OSARCH "x64")
		ENDIF ()
	ELSE ()
		IF (CMAKE_HOST_SYSTEM_PROCESSOR MATCHES "(.*i.86.*)|(i86.*)")
			SET (OSARCH "x86")
		ELSEIF (CMAKE_HOST_SYSTEM_PROCESSOR  MATCHES "(.*x86_64.*)|(.*amd64.*)")
			SET (OSARCH "x64")
		ELSEIF (CMAKE_HOST_SYSTEM_PROCESSOR  MATCHES "(.*sparc.*)|(sun4u)")
			SET (OSARCH "sparc")
		ELSEIF (CMAKE_HOST_SYSTEM_PROCESSOR  MATCHES "(.*power.*)|(.*ppc.*)|(.*Power.*)|(000.*)")
			SET (OSARCH "ppc")
		ELSEIF (CMAKE_HOST_SYSTEM_PROCESSOR  MATCHES ".*arm.*b.*")
			SET (OSARCH "armb")
		ELSEIF (CMAKE_HOST_SYSTEM_PROCESSOR  MATCHES ".*arm.*l.*")
			SET (OSARCH "arml")
		ENDIF ()
	ENDIF ()

	# Special handling for mac.
	IF (CMAKE_SYSTEM_NAME STREQUAL "Darwin")
		IF (CMAKE_OSX_ARCHITECTURES STREQUAL "i386")
			SET (OSARCH "x86")
			SET (OSBITS "32")
		ELSEIF (CMAKE_OSX_ARCHITECTURES STREQUAL "x86_64")
			SET (OSARCH "x64")
			SET (OSBITS "64")
		ELSEIF (CMAKE_OSX_ARCHITECTURES STREQUAL "armv7" OR CMAKE_OSX_ARCHITECTURES STREQUAL "armv7s")
			SET (OSARCH "arm7")
			SET (OSBITS "32")
		ELSEIF (CMAKE_OSX_ARCHITECTURES STREQUAL "arm64")
			SET (OSARCH "arm64")
			SET (OSBITS "64")
		ELSE ()
			SET (OSARCH "fat")
			SET (OSBITS "")
		ENDIF ()
	ENDIF ()

	# We're goign to say if we have a conclift we resolve by being x86 and 32 bit.
	IF (OSARCH STREQUAL "x64" AND OSBITS STREQUAL "32")
		SET (OSARCH "x86")
	ENDIF ()
	IF (OSARCH STREQUAL "x86" AND OSBITS STREQUAL "64")
		SET (OSBITS "32")
	ENDIF ()
ENDIF ()

# OSTYPE, OSVER, OSEXT

IF (NOT OSVER)
	SET (OSVER "")
ENDIF ()
IF (NOT OSEXT)
	SET (OSEXT "")
ENDIF ()
IF (NOT OSTYPE)
	SET (OSTYPE "")
	SET (OSVER "")
	SET (OSEXT "")

	IF (WIN32)
		SET (OSTYPE "windows")
	ELSEIF (ANDROID)
		SET (OSTYPE "android")
	ELSEIF (IOSSIM OR IPHONESIMULATOR)
		SET (OSTYPE "iphonesimulator")
	ELSEIF (IOS OR IPHONEOS)
		SET (OSTYPE "iphoneos")
	ELSE ()
		IF (CMAKE_SYSTEM_NAME STREQUAL "AIX")
			SET (OSTYPE "aix")
			EXEC_PROGRAM ("oslevel" OUTPUT_VARIABLE AIX_OSLEVEL)
			IF (AIX_OSLEVEL MATCHES "(5\.1)|(5\.3)")
				SET (OSVER "5")
			ELSE ()
				SET (OSVER "4")
			ENDIF ()
			IF (OSBITS STREQUAL "32")
				SET (OSEXT "${OSVER}-32bit")
			ELSE ()
				SET (OSEXT "${OSVER}-64bit")
			ENDIF ()
		ELSEIF (CMAKE_SYSTEM_NAME STREQUAL "Darwin")
			SET (OSTYPE "macosx")
		ELSEIF (CMAKE_SYSTEM_NAME STREQUAL "FreeBSD")
			SET (OSTYPE "freebsd")
			EXEC_PROGRAM ("uname -r | cut -d . -f 1" OUTPUT_VARIABLE OSVER)
			SET (OSEXT "${OSVER}")
		ELSEIF (CMAKE_SYSTEM_NAME STREQUAL "OpenBSD")
			SET (OSTYPE "openbsd")
			EXEC_PROGRAM ("uname -r | cut -b 1" OUTPUT_VARIABLE OSVER)
			SET (OSEXT "${OSVER}")
		ELSEIF (CMAKE_SYSTEM_NAME STREQUAL "NetBSD")
			SET (OSTYPE "netbsd")
			EXEC_PROGRAM ("uname -r | cut -d . -f 1" OUTPUT_VARIABLE OSVER)
			SET (OSEXT "${OSVER}")
		ELSEIF (CMAKE_SYSTEM_NAME STREQUAL "HP-UX")
			SET (OSTYPE "hpux")
		ELSEIF (CMAKE_SYSTEM_NAME STREQUAL "Linux")
			SET (OSTYPE "linux")
			EXEC_PROGRAM ("find /lib -name libc-*.so | tail -n 1 | xargs basename | sed -e 's|libc-||' -e 's|.so||'" OUTPUT_VARIABLE GLIBC_VER)
			IF (GLIBC_VER MATCHES "2[.]1[.].*")
				SET (OSEXT "glibc21")
			ELSEIF (GLIBC_VER MATCHES "2[.]2.*")
				SET (OSEXT "glibc22")
			ELSEIF (GLIBC_VER MATCHES "2[.].*")
				SET (OSEXT "glibc23")
			ENDIF ()
		ELSEIF (CMAKE_SYSTEM_NAME STREQUAL "SCO_SV" OR CMAKE_SYSTEM_NAME STREQUAL "UnixWare")
			SET (OSTYPE "sco-osr")
			EXEC_PROGRAM ("uname -v" OUTPUT_VARIABLE SCO_VER)
			IF (SCO_VER STREQUAL "6\.0\.0")
				SET (OSVER "6")
			ELSEIF (SCO_VER STREQUAL "5\.0\.7")
				SET (OSVER "507")
			ELSE ()
				SET (OSVER "5")
			ENDIF ()
			SET (OSEXT "${OSVER}")
		ELSEIF (CMAKE_SYSTEM_NAME STREQUAL "SunOS")
			SET (OSTYPE "solaris")
			EXEC_PROGRAM ("uname -r | cut -b 3-" OUTPUT_VARIABLE OSVER)
			SET (OSEXT "${OSVER}")
		ELSE ()
			SET (OSTYPE "unknown")
		ENDIF ()
	ENDIF ()
ENDIF ()
