# Set dynamic export so all symbols are dynamic to the dynamic symbol table.
# This is required for shared libraries (modules) that are linked to an executable
# and it is also required for an executable that is loaded into another using dlopen.
# 
# The cmake internal dynamic export doesn't work properly on some platforms like Solairs.
#     SET_TARGET_PROPERTIES(${PROJECT_NAME} PROPERTIES ENABLE_EXPORTS TRUE)
# This module forces the proper exports to be enabled.

INCLUDE (DetectPlatform)

MACRO (M_DYNAMICEXPORT)
	IF (OSTYPE STREQUAL "aix")
		SET (FLAG "-Wl,-bexpall")
	ELSEIF (OSTYPE STREQUAL "freebsd")
		SET (FLAG "-Wl,-export-dynamic")
	ELSEIF (OSTYPE STREQUAL "linux")
		SET (FLAG "-Wl,-export-dynamic")
	ELSEIF (OSTYPE STREQUAL "openbsd")
		SET (FLAG  "-Wl,-export-dynamic")
	ELSEIF (OSTYPE STREQUAL "sco-osr")
		SET (FLAG "-Wl,-Bexport")
	ELSEIF (OSTYPE STREQUAL "solaris")
		SET (FLAG "-Wl,-export-dynamic")
	ENDIF ()

	IF (FLAG) 
		SET (DYNAMIC_EXPORT_FLAGS "${FLAG}")
	ELSE ()
		SET (DYNAMIC_EXPORT_FLAGS "")
	ENDIF ()
ENDMACRO ()
