# - Try to find zlib
#
# The CMake provided FindZLIB module doesn't find zlilb properly
# on some platforms like Solaris sparc. It keeps finding the 64b bit
# package even when ZLIB_ROOT is given and points to the 32 bit
# directory. 
#
# Set the following for alternative search path:
#  ZLIB_ROOT_DIR 
#
# Once done this will define:
#  ZLIB_FOUND        - System has zlib 
#  ZLIB_INCLUDE_DIRS - The zlib include directories
#  ZLIB_LIBRARIES    - The libraries needed to use zlib 

IF (ZLIB_INCLUDE_DIRS AND ZLIB_LIBRARIES)
	SET (ZLIB_FOUND TRUE)
ELSE ()
	IF (NOT WIN32)
		FIND_PACKAGE (PkgConfig)
		PKG_CHECK_MODULES (PC_ZLIB QUIET zlib)
	ENDIF ()

	SET (ZLIB_PATH_LOCATIONS
		/usr/local
		/usr/local/zlib
		/usr/local/zlib64
	)

	FIND_PATH (ZLIB_INCLUDE_DIR NAMES zlib.h
		HINTS ${ZLIB_ROOT_DIR} ${PC_ZLIB_INCLUDE_DIRS}
		PATHS ${ZLIB_PATH_LOCATIONS}
		PATH_SUFFIXES include
	)

	FIND_LIBRARY (ZLIB_LIBRARY NAMES z zlib zdll zlib1 zlibd zlibd1
		NAMES_PER_DIR
		HINTS ${ZLIB_ROOT_DIR} ${PC_ZLIB_LIBRARY_DIRS}
		PATHS ${ZLIB_PATH_LOCATIONS}
		PATH_SUFFIXES lib ""
	)

	# set ZLIB_FOUND to TRUE if all listed variables are TRUE.
	INCLUDE (FindPackageHandleStandardArgs)
	FIND_PACKAGE_HANDLE_STANDARD_ARGS (ZLIB DEFAULT_MSG ZLIB_INCLUDE_DIR ZLIB_LIBRARY)

	IF (ZLIB_FOUND)
		SET (ZLIB_INCLUDE_DIRS ${ZLIB_INCLUDE_DIR})
		SET (ZLIB_LIBRARIES ${ZLIB_LIBRARY})
	ENDIF ()

	MARK_AS_ADVANCED (ZLIB_INCLUDE_DIR ZLIB_LIBRARY)
ENDIF ()


