# - Try to find libusb
#
# Set the following for alternative search path:
#  LIBUSB_ROOT_DIR 
#
# Once done this will define:
#  LIBUSB_FOUND        - System has libusb
#  LIBUSB_INCLUDE_DIRS - The libusb include directories
#  LIBUSB_LIBRARIES    - The libraries needed to use libusb

IF (LIBUSB_INCLUDE_DIRS AND LIBUSB_LIBRARIES)
	SET (LIBUSB_FOUND TRUE)
ELSE ()
	IF (NOT WIN32)
		FIND_PACKAGE (PkgConfig)
		PKG_CHECK_MODULES (PC_LIBUSB QUIET libusb-1.0)
	ENDIF ()

	SET (LIBUSB_PATH_LOCATIONS
		/usr/local
		/usr/local/libusb
		/usr/local/libusb64
	)

	FIND_PATH (LIBUSB_INCLUDE_DIR NAMES libusb.h
		HINTS ${LIBUSB_ROOT_DIR} ${PC_LIBUSB_INCLUDE_DIRS}
		PATHS ${LIBUSB_PATH_LOCATIONS}
		PATH_SUFFIXES include libusb-1.0 include/libusb-1.0
	)

	FIND_LIBRARY (LIBUSB_LIBRARY NAMES usb-1.0
		NAMES_PER_DIR
		HINTS ${LIBUSB_ROOT_DIR} ${PC_LIBUSB_LIBRARY_DIRS}
		PATHS ${LIBUSB_PATH_LOCATIONS}
		PATH_SUFFIXES lib ""
	)

	# set LIBUSB_FOUND to TRUE if all listed variables are TRUE.
	INCLUDE (FindPackageHandleStandardArgs)
	FIND_PACKAGE_HANDLE_STANDARD_ARGS (LIBUSB DEFAULT_MSG LIBUSB_INCLUDE_DIR LIBUSB_LIBRARY)

	IF (LIBUSB_FOUND)
		SET (LIBUSB_INCLUDE_DIRS ${LIBUSB_INCLUDE_DIR})
		SET (LIBUSB_LIBRARIES ${LIBUSB_LIBRARY})
	ENDIF ()

	MARK_AS_ADVANCED (LIBUSB_INCLUDE_DIR LIBUSB_LIBRARY)
ENDIF ()
