# - Try to find mstdlib_io
#
# Set the following for alternative search path:
#  MSTDLIB_ROOT_DIR 
#
# Once done this will define:
#  MSTDLIB_IO_FOUND        - System has mstdlib_io
#  MSTDLIB_IO_INCLUDE_DIRS - The mstdlib_io include directories
#  MSTDLIB_IO_LIBRARIES    - The libraries needed to use mstdlib_io
IF (MSTDLIB_IO_INCLUDE_DIRS AND MSTDLIB_IO_LIBRARIES)
	SET (MSTDLIB_IO_FOUND TRUE)
ELSE ()
	# Thread requires base so we need to ensure we have it.
	FIND_PACKAGE (MSTDLIBBase REQUIRED)

	IF (NOT WIN32)
		FIND_PACKAGE (PkgConfig)
		PKG_CHECK_MODULES (PC_MSTDLIB_IO QUIET mstdlib_io)
	ENDIF ()

	SET (MSTDLIB_IO_PATH_LOCATIONS
		/usr/local
		/usr/local/mstdlib
		/usr/local/mstdlib64
	)

	FIND_PATH (MSTDLIB_IO_INCLUDE_DIR NAMES mstdlib_io.h
		HINTS ${MSTDLIB_ROOT_DIR} ${PC_MSTDLIB_IO_INCLUDE_DIRS}
		PATHS ${MSTDLIB_IO_PATH_LOCATIONS}
		PATH_SUFFIXES include mstdlib include/mstdlib
	)
	STRING (REGEX REPLACE "mstdlib(/)*$" "" MSTDLIB_IO_INCLUDE_DIR "${MSTDLIB_IO_INCLUDE_DIR}")

	FIND_LIBRARY (MSTDLIB_IO_LIBRARY NAMES mstdlib_io
		NAMES_PER_DIR
		HINTS ${MSTDLIB_ROOT_DIR} ${PC_MSTDLIB_IO_LIBRARY_DIRS}
		PATHS ${MSTDLIB_IO_PATH_LOCATIONS}
		PATH_SUFFIXES lib "" io io/.libs build build/bin build/lib
	)

	# set MSTDLIB_IO_FOUND to TRUE if all listed variables are TRUE.
	INCLUDE (FindPackageHandleStandardArgs)
	FIND_PACKAGE_HANDLE_STANDARD_ARGS (MSTDLIB_IO DEFAULT_MSG MSTDLIB_IO_INCLUDE_DIR MSTDLIB_IO_LIBRARY)

	IF (MSTDLIB_IO_FOUND)
		SET (MSTDLIB_IO_INCLUDE_DIRS ${MSTDLIB_IO_INCLUDE_DIR})
		SET (MSTDLIB_IO_LIBRARIES ${MSTDLIB_IO_LIBRARY})
	ENDIF ()

	MARK_AS_ADVANCED (MSTDLIB_IO_INCLUDE_DIR MSTDLIB_IO_LIBRARY)
ENDIF ()

