# - Check for getgrnam function.
# Once done this will set one of the following:
#  HAVE_GETGRNAM_5 - Takes 5 arguments.
#  HAVE_GETGRNAM_4 - Takes 4 arguments.
#  HAVE_GETGRNAM_1 - Takes 1 argument. Not reentrant.
#  HAVE_GETGRNAM_0 - Does not support getgrnam function.

INCLUDE (CheckCSourceCompiles)

MACRO (M_CHECK_GETGRNAM)
	# 5 args.
	IF (NOT HAVE_GETGRNAM_5)
		CHECK_C_SOURCE_COMPILES ("
				#include <grp.h>
				#include <sys/types.h>
				int main(int argc, char **argv) {
					struct group   grp;
					struct group  *grp_result;
					char           pg_buf[16384];
					(void)getgrnam_r(\"a\", &grp, pg_buf, sizeof(pg_buf), &grp_result);
					return 0;
				}
			"
			HAVE_GETGRNAM_5
		)
	ENDIF ()
	# 4 args.
	IF (NOT HAVE_GETGRNAM_5)
		CHECK_C_SOURCE_COMPILES ("
				#include <grp.h>
				#include <sys/types.h>
				int main(int argc, char **argv) {
					struct group   grp;
					char           pg_buf[16384];
					(void)getgrnam_r(\"a\", &grp, pg_buf, sizeof(pg_buf));
					return 0;
				}
			"
			HAVE_GETGRNAM_4
		)
	ENDIF()
	# 1 args.
	IF (NOT HAVE_GETGRNAM_5 AND NOT HAVE_GETGRNAM_4)
		CHECK_C_SOURCE_COMPILES ("
				#include <grp.h>
				#include <sys/types.h>
				int main(int argc, char **argv) {
					(void)getgrnam(\"a\");
					return 0;
				}
			"
			HAVE_GETGRNAM_1
		)
	ENDIF ()

	IF (HAVE_GETGRNAM_5 OR HAVE_GETGRNAM_4)
		SET (HAVE_GETGRNAM_R 1)
	ENDIF ()

	IF (NOT HAVE_GETGRNAM_5 AND NOT HAVE_GETGRNAM_4 AND NOT HAVE_GETGRNAM_1)
		SET (HAVE_GETGRNAM_0 1)
	ENDIF ()
ENDMACRO ()

