# - Check for gethostbyname_r function.
# Once done this will set one of the following:
#  HAVE_GETHOSTBYNAME_6 - Takes 6 arguments.
#  HAVE_GETHOSTBYNAME_5 - Takes 5 arguments.
#  HAVE_GETHOSTBYNAME_3 - Takes 3 arguments.
#  HAVE_GETHOSTBYNAME_1 - Takes 1 argument. Not reentrant.
#  HAVE_GETHOSTBYNAME_0 - Does not support gethostbyname function.

INCLUDE (CheckCSourceCompiles)
INCLUDE (CommonLibraries)

M_CHECKCOMMONLIBRARIES()

MACRO (M_CHECK_GETHOSTBYNAME)
	SET (MYCMAKE_REQUIRED_LIBRARIES ${CMAKE_REQUIRED_LIBRARIES})

	IF (HAVE_LINK_NSL)
		SET (CMAKE_REQUIRED_LIBRARIES "${CMAKE_REQUIRED_LIBRARIES} ${nsl}")
	ENDIF ()

	# 6 args.
	CHECK_C_SOURCE_COMPILES ("
			#include <netdb.h>
			int main(int argc, char **argv) {
				struct hostent *he;
				struct hostent *res;
				char            buf[2048];
				int             h_errnop;
				(void)gethostbyname_r(\"a\", he, buf, sizeof(buf), &res, &h_errnop);
				return 0;
			}
		"
		HAVE_GETHOSTBYNAME_6
	)
	# 5 args.
	IF (NOT HAVE_GETHOSTBYNAME_6)
		CHECK_C_SOURCE_COMPILES ("
				#include <netdb.h>
				int main(int argc, char **argv) {
					struct hostent *he;
					char            buf[2048];
					int             h_errnop;
					(void)gethostbyname_r(\"a\", he, buf, sizeof(buf), &h_errnop);
					return 0;
				}
			"
			HAVE_GETHOSTBYNAME_5
		)
	ENDIF ()
	# 3 args.
	IF (NOT HAVE_GETHOSTBYNAME_6 AND NOT HAVE_GETHOSTBYNAME_5)
		CHECK_C_SOURCE_COMPILES ("
				#include <netdb.h>
				int main(int argc, char **argv) {
					struct hostent      *he;
					struct hostent_data  data;
					(void)gethostbyname_r(\"a\", he, &data);
					return 0;
				}
			"
			HAVE_GETHOSTBYNAME_3
		)
	ENDIF()
	# 1 args.
	IF (NOT HAVE_GETHOSTBYNAME_6 AND NOT HAVE_GETHOSTBYNAME_5 AND NOT HAVE_GETHOSTBYNAME_3)
		CHECK_C_SOURCE_COMPILES ("
				#include <netdb.h>
				int main(int argc, char **argv) {
					(void)gethostbyname(\"a\");
					return 0;
				}
			"
			HAVE_GETHOSTBYNAME_1
		)
	ENDIF ()

	IF (HAVE_GETHOSTBYNAME_6 OR HAVE_GETHOSTBYNAME_5 OR HAVE_GETHOSTBYNAME_3)
		SET (HAVE_GETHOSTBYNAME_R 1)
	ENDIF ()

	IF (NOT HAVE_GETHOSTBYNAME_6 AND NOT HAVE_GETHOSTBYNAME_5 AND NOT HAVE_GETHOSTBYNAME_3 AND NOT HAVE_GETHOSTBYNAME_1)
		SET (HAVE_GETHOSTBYNAME_0 1)
	ENDIF ()

	SET (CMAKE_REQUIRED_LIBRARIES ${MYCMAKE_REQUIRED_LIBRARIES})
ENDMACRO ()
