# - Check for getpwnam function.
# Once done this will set one of the following:
#  HAVE_GETPWNAM_5 - Takes 5 arguments.
#  HAVE_GETPWNAM_4 - Takes 4 arguments.
#  HAVE_GETPWNAM_1 - Takes 1 argument. Not reentrant.
#  HAVE_GETPWNAM_0 - Does not support getpwnam function.

INCLUDE (CheckCSourceCompiles)

MACRO (M_CHECK_GETPWNAM)
	# 5 args.
	IF (NOT HAVE_GETPWNAM_5)
		CHECK_C_SOURCE_COMPILES ("
				#include <pwd.h>
				#include <sys/types.h>
				#include <unistd.h>
				int main(int argc, char **argv) {
					struct passwd *pwd_result;
					struct passwd  pwd;
					char           pbuf[16384];
					(void)getpwnam_r(\"a\", &pwd, pbuf, sizeof(pbuf), &pwd_result);
					return 0;
				}
			"
			HAVE_GETPWNAM_5
		)
	ENDIF ()
	# 4 args.
	IF (NOT HAVE_GETPWNAM_5)
		CHECK_C_SOURCE_COMPILES ("
				#include <pwd.h>
				#include <sys/types.h>
				#include <unistd.h>
				int main(int argc, char **argv) {
					struct passwd  pwd;
					char           pbuf[16384];
					(void)getpwnam_r(\"a\", &pwd, pbuf, sizeof(pbuf));
					return 0;
				}
			"
			HAVE_GETPWNAM_4
		)
	ENDIF()
	# 1 args.
	IF (NOT HAVE_GETPWNAM_5 AND NOT HAVE_GETPWNAM_4)
		CHECK_C_SOURCE_COMPILES ("
				#include <pwd.h>
				#include <sys/types.h>
				#include <unistd.h>
				int main(int argc, char **argv) {
					(void)getpwnam(\"a\");
					return 0;
				}
			"
			HAVE_GETPWNAM_1
		)
	ENDIF ()

	IF (HAVE_GETPWNAM_5 OR HAVE_GETPWNAM_4)
		SET (HAVE_GETPWNAM_R 1)
	ENDIF ()

	IF (NOT HAVE_GETPWNAM_5 AND NOT HAVE_GETPWNAM_4 AND NOT HAVE_GETPWNAM_1)
		SET (HAVE_GETPWNAM_0 1)
	ENDIF ()
ENDMACRO ()
