# - Check for various cflags and linker supported by the compiler to harden the build.

INCLUDE (CheckCCompilerFlag)

MACRO (M_HARDEN)
	IF (NOT M_HARDEN_RUN)
		# Save these.
		SET (MYCMAKE_REQUIRED_FLAGS ${CMAKE_REQUIRED_FLAGS})

		SET (CMAKE_POSITION_INDEPENDENT_CODE ON)
		#SET (CMAKE_SKIP_RPATH ON)

		SET (C_FLAGS
			#"-fvisibility=hidden"
			)
		SET (LINKER_FLAGS
			#"-Wl,--no-undefined"
			"-Wl,--allow-shlib-undefined"
			"-Wl,--as-needed"
			"-Wl,-z,noexecstack"
			"-Wl,-z,relro,-z,now"
			)
		SET (LINKER_FLAGS_EXE_ONLY
			"-pie"
			)
		IF (WIN32 AND MSVC)
			SET (WIN32_C_FLAGS
				"-gs"
				)
			SET (WIN32_LINKER_FLAGS
				#"-safeseh"
				"-nxcompat"
				#"-dynamicbase"
				)
		ENDIF ()

		# Check and set compiler flags.
		FOREACH (flag ${C_FLAGS})
			CHECK_C_COMPILER_FLAG(${flag} HAVE_${flag})
			IF (HAVE_${flag})
				SET (CMAKE_C_FLAGS "${CMAKE_C_FLAGS} ${flag}")
			ENDIF ()
		ENDFOREACH ()

		# Check and set linker flags.
		FOREACH (flag ${LINKER_FLAGS})
			SET (CMAKE_REQUIRED_FLAGS ${flag})
			CHECK_C_COMPILER_FLAG ("" HAVE_${flag})
			IF (HAVE_${flag})
				SET (CMAKE_EXE_LINKER_FLAGS "${CMAKE_EXE_LINKER_FLAGS} ${flag}")
				SET (CMAKE_SHARED_LINKER_FLAGS "${CMAKE_SHARED_LINKER_FLAGS} ${flag}")
			ENDIF ()
		ENDFOREACH ()

		# Check and set exe only linker flags.
		FOREACH (flag ${LINKER_FLAGS_EXE_ONLY})
			SET (CMAKE_REQUIRED_FLAGS ${flag})
			CHECK_C_COMPILER_FLAG ("" HAVE_${flag})
			IF (HAVE_${flag})
				SET (CMAKE_EXE_LINKER_FLAGS "${CMAKE_EXE_LINKER_FLAGS} ${flag}")
			ENDIF ()
		ENDFOREACH ()

		# Windows specific flags. The variable won't be set if not on Windows.
		FOREACH (flag ${WIN32_C_FLAGS})
			CHECK_C_COMPILER_FLAG(${flag} HAVE_${flag})
			IF (HAVE_${flag})
				SET (CMAKE_C_FLAGS "${CMAKE_C_FLAGS} ${flag}")
			ENDIF ()
		ENDFOREACH ()

		FOREACH (flag ${WIN32_LINKER_FLAGS})
			SET (CMAKE_REQUIRED_FLAGS ${flag})
			CHECK_C_COMPILER_FLAG ("" HAVE_${flag})
			IF (HAVE_${flag})
				SET (CMAKE_EXE_LINKER_FLAGS "${CMAKE_EXE_LINKER_FLAGS} ${flag}")
				SET (CMAKE_SHARED_LINKER_FLAGS "${CMAKE_SHARED_LINKER_FLAGS} ${flag}")
			ENDIF ()
		ENDFOREACH ()

		SET (CMAKE_REQUIRED_FLAGS ${MYCMAKE_REQUIRED_FLAGS})

		SET (M_HARDEN_RUN YES CACHE INTERNAL "")
	ENDIF ()
ENDMACRO ()
