# - Check for large file support.
# Once done this will set the following if found:
#  _LARGE_FILES
#  _LARGE_FILE_SOURCE
#  _FILE_OFFSET_BITS=X

INCLUDE (CheckCSourceRuns)

MACRO (M_TEST_LARGE_FILES)
	SET (LARGE_FILE_SRC "
		#include <sys/types.h>
		#define LARGE_OFF_T (((off_t) 1 << 62) - 1 + ((off_t) 1 << 62))
		int main(int argc, char **argv) {
			int off_t_is_large[(LARGE_OFF_T % 2147483629 == 721 && LARGE_OFF_T % 2147483647 == 1) ? 1 : -1];
			return 0;
		}
		"
	)

	SET (LARGE_FILE_EXTRA_SRC "
		#include <sys/types.h>
		int main(int argc, char **argv) {
			return sizeof(off_t) == 8 ? 0 : 1;
		}
		"
	)

	# Check if off_t is 64 bit and we don't need to set anything.
	CHECK_C_SOURCE_RUNS ("${LARGE_FILE_SRC}" HAVE_LARGE_FILE_SUPPORT)
	SET (OFF_TYPE "native")

	# Check if we need to set _FILE_OFFSET_BITS=64.
	IF (NOT HAVE_LARGE_FILE_SUPPORT)
		CHECK_C_SOURCE_RUNS ("#define _FILE_OFFSET_BITS 64\n${LARGE_FILE_EXTRA_SRC}" HAVE_LARGE_FILE_SUPPORT)
		IF (HAVE_LARGE_FILE_SUPPORT)
			SET (OFF_TYPE "_FILE_OFFSET_BITS=64")
			SET (_FILE_OFFSET_BITS 64)
		ENDIF ()
	ENDIF ()

	# Check if we need to set _LARGE_FILES
	IF (NOT HAVE_LARGE_FILE_SUPPORT)
		CHECK_C_SOURCE_RUNS ("#define _LARGE_FILES\n${LARGE_FILE_EXTRA_SRC}" HAVE_LARGE_FILE_SUPPORT)
		IF (HAVE_LARGE_FILE_SUPPORT)
			SET (OFF_TYPE "_LARGE_FILES")
			SET (_LARGE_FILES 1)
		ENDIF ()
	ENDIF ()

	# Check if we need to set _LARGE_FILE_SOURCE
	IF (NOT HAVE_LARGE_FILE_SUPPORT)
		CHECK_C_SOURCE_RUNS ("#define _LARGE_FILE_SOURCE\n${LARGE_FILE_EXTRA_SRC}" HAVE_LARGE_FILE_SUPPORT)
		IF (HAVE_LARGE_FILE_SUPPORT)
			SET (OFF_TYPE "_LARGE_FILE_SOURCE")
			SET (_LARGE_FILE_SOURCE 1)
		ENDIF ()
	ENDIF ()

	# Let the caller know what happened.
	IF (HAVE_LARGE_FILE_SUPPORT)
		MESSAGE (STATUS "64-bit off_t - present with ${OFF_TYPE}")
	ELSEIF ()
		MESSAGE (STATUS "64-bit off_t - not present")
	ENDIF ()
ENDMACRO ()
