# - Check for readdir function.
# Once done this will set one of the following:
#  HAVE_READDIR_3 - Takes 5 arguments.
#  HAVE_READDIR_2 - Takes 4 arguments.
#  HAVE_READDIR_1 - Takes 1 argument. Not reentrant.
#  HAVE_READDIR_0 - Does not support readdir function.

INCLUDE (CheckCSourceCompiles)

MACRO (M_CHECK_READDIR)
	# 3 args.
	IF (NOT HAVE_READDIR_3)
		CHECK_C_SOURCE_COMPILES ("
				#include <dirent.h>
				#include <stddef.h>
				#include <stdlib.h>
				#include <string.h>
				#include <sys/types.h>
				int main(int argc, char **argv) {
					DIR           *dir;
					struct dirent *entry;
					struct dirent *result;
					size_t         len;
					len   = offsetof(struct dirent, d_name) + 16385;
					entry = malloc(len);
					memset(entry, 0, len);
					dir = opendir(\".\");
					(void)readdir_r(dir, entry, &result); 
					free(entry);
					closedir(dir);
					return 0;
				}
			"
			HAVE_READDIR_3
		)
	ENDIF ()
	# 2 args.
	IF (NOT HAVE_READDIR_3)
		CHECK_C_SOURCE_COMPILES ("
				#include <dirent.h>
				#include <stddef.h>
				#include <stdlib.h>
				#include <string.h>
				#include <sys/types.h>
				int main(int argc, char **argv) {
					DIR           *dir;
					struct dirent *entry;
					size_t         len;
					len   = offsetof(struct dirent, d_name) + 16385;
					entry = malloc(len);
					memset(entry, 0, len);
					dir = opendir(\".\");
					(void)readdir_r(dir, entry); 
					free(entry);
					closedir(dir);
					return 0;
				}
			"
			HAVE_READDIR_2
		)
	ENDIF()
	# 1 args.
	IF (NOT HAVE_READDIR_3 AND NOT HAVE_READDIR_2)
		CHECK_C_SOURCE_COMPILES ("
				#include <dirent.h>
				#include <sys/types.h>
				int main(int argc, char **argv) {
					DIR           *dir;
					dir = opendir(\".\");
					(void)readdir(dir);
					closedir(dir);
					return 0;
				}
			"
			HAVE_READDIR_1
		)
	ENDIF ()

	IF (HAVE_READDIR_3 OR HAVE_READDIR_2)
		SET (HAVE_READDIR_R 1)
	ENDIF ()

	IF (NOT HAVE_READDIR_3 AND NOT HAVE_READDIR_2 AND NOT HAVE_READDIR_1)
		SET (HAVE_READDIR_0 1)
	ENDIF ()
ENDMACRO ()

