# - Check for various cflags supported by the compiler and set them.
# Can pass in CFlags to use. E.g M_SET_C_FLAGS (-Wconversion -Wextra -Wnon-exist) or call without CFlags to
# use the default list of CFlags.
# Once done this will set all of the supported cflags.

INCLUDE (CheckCCompilerFlag)

MACRO (M_SET_C_FLAGS)
	SET (EXTRA_ARGS ${ARGN})
	LIST (LENGTH EXTRA_ARGS NUM_EXTRA_ARGS)

	IF (${NUM_EXTRA_ARGS} GREATER 0)
		FOREACH (ARG ${EXTRA_ARGS})
			LIST (APPEND COMPILER_FLAGS ${ARG})
		ENDFOREACH ()
	ELSE ()
		# Default compiler flags we want enabled if supported.
		SET (COMPILER_FLAGS
			-W -Wextra -Wchar-subscripts -Wcomment -Wno-coverage-mismatch
			-Wdouble-promotion -Wformat -Wnonnull -Winit-self -Wimplicit-int
			-Wimplicit-function-declaration -Wimplicit -Wignored-qualifiers -Wmain
			-Wmissing-braces -Wmissing-include-dirs -Wparentheses -Wsequence-point
			-Wreturn-type -Wswitch -Wtrigraphs -Wunused-but-set-parameter
			-Wunused-but-set-variable -Wunused-function -Wunused-label
			-Wunused-local-typedefs -Wunused-parameter -Wunused-variable -Wunused-value
			-Wunused -Wuninitialized -Wmaybe-uninitialized -Wunknown-pragmas
			-Wmissing-format-attribute -Warray-bounds
			-Wtrampolines -Wfloat-equal
			-Wdeclaration-after-statement -Wundef -Wshadow -Wunsafe-loop-optimizations
			-Wpointer-arith -Wtype-limits -Wbad-function-cast -Wcast-qual
			-Wcast-align -Wwrite-strings -Wclobbered -Wempty-body
			-Wenum-compare -Wjump-misses-init -Wsign-compare -Wsizeof-pointer-memaccess
			-Waddress -Wlogical-op -Waggregate-return
			-Wstrict-prototypes -Wold-style-declaration -Wold-style-definition
			-Wmissing-parameter-type -Wmissing-prototypes -Wmissing-declarations
			-Wmissing-field-initializers -Woverride-init -Wpacked -Wredundant-decls
			-Wnested-externs -Winline -Winvalid-pch -Wvariadic-macros -Wvarargs
			-Wvector-operation-performance -Wvla -Wpointer-sign
			-Wdisabled-optimization -Wendif-labels -Wpacked-bitfield-compat
			-Wformat-security -Woverlength-strings -Wstrict-aliasing
			-Wstrict-overflow -Wsync-nand -Wvolatile-register-var
			-Wconversion -Wsign-conversion
		)
		IF (WIN32)
			# W4 would be better but it produces unnecessary warnings like:
			# *  warning C4706: assignment within conditional expression
			#     Triggered when doing "while(1)"
			# * warning C4115: 'timeval' : named type definition in parentheses
			# * warning C4201: nonstandard extension used : nameless struct/union
			#     Triggered by system includes (commctrl.h, shtypes.h, Shlobj.h)
			LIST (APPEND COMPILER_FLAGS "-W3")
		ELSE ()
			# This causes unnecessary warnings on windows.
			LIST (APPEND COMPILER_FLAGS "-Wall")
		ENDIF ()
	ENDIF ()

	# Check and set compiler flags.
	FOREACH (flag ${COMPILER_FLAGS})
		CHECK_C_COMPILER_FLAG (${flag} HAVE_${flag})
		IF (HAVE_${flag})
			SET (CMAKE_C_FLAGS "${CMAKE_C_FLAGS} ${flag}")
		ENDIF ()
	ENDFOREACH ()
ENDMACRO ()
