# - Check for various system extensions.
# Once done this will set the following if found:
#  _GNU_SOURCE              - Extensions for GNU/Linux.
#  _MINIX                   - Identify Minix platform.
#  _POSIX_1_SOURCE          - Additional Posix functions for Minix.
#  _POSIX_SOURCE            - Posix founctions for Minix.
#  __EXTENSIONS__           - General extensions for Solaris.
#  _POSIX_PTHREAD_SEMANTICS - Thread extensions for Solaris.
#  _ALL_SOURCE              - Extension for AIX 3.
# Once done set the following CFLAGS if found:
#  _XOPEN_SOURCE=500        - Enables some additional functions.
#  _REENTRANT               - Needed on SCO for gethostbyname_r.

INCLUDE (CheckSymbolExists)

MACRO (M_CHECK_SYSTEM_EXTENSIONS)
	CHECK_SYMBOL_EXISTS (__GNU_LIBRARY__ features.h _GNU_SOURCE)
	CHECK_SYMBOL_EXISTS (_MINIX stdio.h _MINIX)
	CHECK_SYMBOL_EXISTS (_POSIX_1_SOURCE stdio.h _POSIX_1_SOURCE)
	CHECK_SYMBOL_EXISTS (_POSIX_SOURCE stdio.h _POSIX_SOURCE)

	IF (${CMAKE_SYSTEM_NAME} MATCHES "Darwin")
		SET (CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -D_XOPEN_SOURCE=500 -D_DARWIN_C_SOURCE")
	ELSEIF (${CMAKE_SYSTEM_NAME} MATCHES "SCO_SV" OR ${CMAKE_SYSTEM_NAME} MATCHES "UnixWare")
		SET (CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -D_REENTRANT")
	ELSEIF (${CMAKE_SYSTEM_NAME} MATCHES "SunOS")
		SET (CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -std=gnu99 -D_REENTRANT -D_POSIX_PTHREAD_SEMANTICS -D__EXTENSIONS__ ")
	ELSEIF (${CMAKE_SYSTEM_NAME} MATCHES "AIX")
		SET (CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -D_XOPEN_SOURCE=500 -D_ALL_SOURCE ")
	ENDIF ()
	SET (M_CHECK_SYSTEM_EXTENSIONS_RUN YES CACHE INTERNAL "")
ENDMACRO ()
